@@ -5,21 +5,19 @@
  * (at your option) any later version.
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-
 package games.strategy.engine.data;
 
+@SuppressWarnings("serial")
 public class DefaultUnitFactory implements IUnitFactory
 {
-
-    public Unit createUnit(UnitType type, PlayerID owner, GameData data)
-    {
-        return new Unit(type,owner,data);
-    }
-
+	public Unit createUnit(final UnitType type, final PlayerID owner, final GameData data)
+	{
+		return new Unit(type, owner, data);
+	}
 }
