@@ -1,23 +1,20 @@
 /*
  * GameParseException.java
- *
+ * 
  * Created on October 22, 2001, 8:54 AM
  */
-
 package games.strategy.engine.data;
 
 /**
- *
- * @author  Sean Bridges
+ * 
+ * @author Sean Bridges
  * @version 1.0
  */
-public class GameParseException extends Exception 
+@SuppressWarnings("serial")
+public class GameParseException extends Exception
 {
-
-	
-	public GameParseException(String error)
+	public GameParseException(final String error)
 	{
 		super(error);
 	}
-
 }
