@@ -5,38 +5,39 @@
  * (at your option) any later version.
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-
 /*
  * RepairRuleList.java
- *
+ * 
  * Created on October 22, 2001, 10:23 AM
  */
-
 package games.strategy.engine.data;
 
-import java.util.*;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.Map;
 
 /**
- *
- * @author  Kevin Comcowich
+ * 
+ * @author Kevin Comcowich
  * @version 1.0
  */
+@SuppressWarnings("serial")
 public class RepairRuleList extends GameDataComponent
 {
 	private final Map<String, RepairRule> m_repairRules = new HashMap<String, RepairRule>();
 	
-    public RepairRuleList(GameData data) 
+	public RepairRuleList(final GameData data)
 	{
 		super(data);
-    }
+	}
 	
-	protected void addRepairRule(RepairRule pf)
+	protected void addRepairRule(final RepairRule pf)
 	{
 		m_repairRules.put(pf.getName(), pf);
 	}
@@ -46,12 +47,13 @@ public class RepairRuleList extends GameDataComponent
 		return m_repairRules.size();
 	}
 	
-	public RepairRule getRepairRule(String name)
+	public RepairRule getRepairRule(final String name)
 	{
 		return m_repairRules.get(name);
 	}
-
-	public Collection<RepairRule> getRepairRules() {
+	
+	public Collection<RepairRule> getRepairRules()
+	{
 		return m_repairRules.values();
 	}
-}
\ No newline at end of file
+}
