@@ -5,24 +5,22 @@
  * (at your option) any later version.
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-
-
 /*
  * IAttachmentExporter.java
- *
+ * 
  * Created on May 29, 2011, 12:00 PM by Edwin van der Wal
  */
-
 package games.strategy.engine.data.export;
 
 import games.strategy.engine.data.IAttachment;
 
-public interface IAttachmentExporter {
+public interface IAttachmentExporter
+{
 	public String getAttachmentOptions(IAttachment attachment);
 }
