@@ -5,70 +5,65 @@ import java.io.InputStream;
 import java.net.MalformedURLException;
 import java.net.URL;
 
-public class DownloadRunnable implements Runnable {
-
-	
+public class DownloadRunnable implements Runnable
+{
 	private final String urlString;
 	private volatile byte[] contents;
 	private volatile String error;
-
-	public DownloadRunnable(String urlString) {
+	
+	public DownloadRunnable(final String urlString)
+	{
 		super();
 		this.urlString = urlString;
 	}
-
-
-
-	public byte[] getContents() {
+	
+	public byte[] getContents()
+	{
 		return contents;
 	}
-
-
-
-	public void setContents(byte[] contents) {
+	
+	public void setContents(final byte[] contents)
+	{
 		this.contents = contents;
 	}
-
-
-
-	public String getError() {
+	
+	public String getError()
+	{
 		return error;
 	}
-
-
-
-	public void setError(String error) {
+	
+	public void setError(final String error)
+	{
 		this.error = error;
 	}
-
-
-
-	public void run() {
-		
+	
+	public void run()
+	{
 		URL url;
-		try {
+		try
+		{
 			url = new URL(urlString.trim());
-			
-		} catch (MalformedURLException e1) {
-			error = "invalid url";							
+		} catch (final MalformedURLException e1)
+		{
+			error = "invalid url";
 			return;
-		}		
+		}
 		InputStream stream;
 		try
 		{
 			stream = url.openStream();
 			try
 			{
-				ByteArrayOutputStream sink = new ByteArrayOutputStream();
+				final ByteArrayOutputStream sink = new ByteArrayOutputStream();
 				InstallMapDialog.copy(sink, stream);
 				contents = sink.toByteArray();
-			} finally {
+			} finally
+			{
 				stream.close();
 			}
-		} catch(Exception e) {
+		} catch (final Exception e)
+		{
 			error = e.getMessage();
 		}
 	}
-	
-	
 }
