@@ -5,13 +5,12 @@
  * (at your option) any later version.
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-
 package games.strategy.engine.lobby.server.userDB;
 
 import java.sql.Connection;
@@ -21,17 +20,16 @@ import java.util.logging.Logger;
 
 public class DbUtil
 {
-    private static final Logger s_logger = Logger.getLogger(DbUtil.class.getName());
-    
-    public static void closeConnection(Connection con)
-    {
-        try
-        {
-            con.close();
-        } catch (SQLException e)
-        {
-            s_logger.log(Level.WARNING, "Error closing connection",e);
-        }
-    }
-
+	private static final Logger s_logger = Logger.getLogger(DbUtil.class.getName());
+	
+	public static void closeConnection(final Connection con)
+	{
+		try
+		{
+			con.close();
+		} catch (final SQLException e)
+		{
+			s_logger.log(Level.WARNING, "Error closing connection", e);
+		}
+	}
 }
