@@ -5,28 +5,25 @@
  * (at your option) any later version.
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-
 package games.strategy.engine.message;
 
 import games.strategy.net.GUID;
 
 public class HubInvocationResults extends InvocationResults
 {
-
-  public HubInvocationResults()
-  {
-      super();
-  }
-
-  public HubInvocationResults(RemoteMethodCallResults results, GUID methodCallID)
-  {
-      super(results, methodCallID);
-  }
-  
-}
\ No newline at end of file
+	public HubInvocationResults()
+	{
+		super();
+	}
+	
+	public HubInvocationResults(final RemoteMethodCallResults results, final GUID methodCallID)
+	{
+		super(results, methodCallID);
+	}
+}
