@@ -5,29 +5,23 @@
  * (at your option) any later version.
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-
-
-
 package games.strategy.triplea.ui;
 
+import games.strategy.ui.ImageScrollModel;
+import games.strategy.ui.ImageScrollerSmallView;
+
 import java.awt.Image;
 
-import games.strategy.ui.*;
-
-
-
 public class MapPanelSmallView extends ImageScrollerSmallView
 {
-
-    public  MapPanelSmallView(Image img, ImageScrollModel model)
-    {
-        super(img, model);
-
-    }
+	public MapPanelSmallView(final Image img, final ImageScrollModel model)
+	{
+		super(img, model);
+	}
 }
