@@ -5,32 +5,27 @@
  * (at your option) any later version.
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-
 package games.strategy.triplea.ui;
 
 public class StringUtil
 {
-
-  public static String plural(String aString, int aCount)
-  {
-    if(aCount == 1)
-      return aString;
-    else
-    {
-      return aString + "s";
-    }
-  }
-
-
-
-  private StringUtil()
-  {
-  }
-
-}
\ No newline at end of file
+	public static String plural(final String aString, final int aCount)
+	{
+		if (aCount == 1)
+			return aString;
+		else
+		{
+			return aString + "s";
+		}
+	}
+	
+	private StringUtil()
+	{
+	}
+}
