@@ -5,36 +5,37 @@
  * (at your option) any later version.
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-
-
 package games.strategy.twoIfBySea.delegate;
 
 /**
- * <p>Title: TripleA</p>
- * <p> </p>
- * <p> Copyright (c) 2002</p>
- * <p> </p>
+ * <p>
+ * Title: TripleA
+ * </p>
+ * <p>
+ * </p>
+ * <p>
+ * Copyright (c) 2002
+ * </p>
+ * <p>
+ * </p>
+ * 
  * @author Sean Bridges
- *
+ * 
  */
-
-import games.strategy.engine.data.GameData;
 import games.strategy.engine.delegate.IDelegateBridge;
 import games.strategy.triplea.delegate.InitializationDelegate;
 
 public class InitDelegate extends InitializationDelegate
 {
-
-	protected void init(GameData data,  IDelegateBridge aBridge)
+	@Override
+	protected void init(final IDelegateBridge aBridge)
 	{
-		super.init(data, aBridge);
-
-
+		super.init(aBridge);
 	}
-}
\ No newline at end of file
+}
