@@ -5,29 +5,25 @@
  * (at your option) any later version.
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-
 package games.strategy.util;
 
-import java.awt.image.*;
 import java.awt.Image;
-
+import java.awt.image.ImageObserver;
 
 public class NullImageObserver implements ImageObserver
 {
-  public NullImageObserver()
-  {
-  }
-
-  public boolean imageUpdate(Image image, int flags, int int2, int int3,
-                             int int4, int int5)
-  {
-    return !((flags & ALLBITS) != 0) || ( (flags & ABORT) != 0);
-
-  }
-}
\ No newline at end of file
+	public NullImageObserver()
+	{
+	}
+	
+	public boolean imageUpdate(final Image image, final int flags, final int int2, final int int3, final int int4, final int int5)
+	{
+		return !((flags & ALLBITS) != 0) || ((flags & ABORT) != 0);
+	}
+}
