@@ -5,13 +5,12 @@
  * (at your option) any later version.
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-
 package games.strategy.engine.lobby.server.userDB;
 
 import games.strategy.util.Util;
@@ -19,21 +18,13 @@ import junit.framework.TestCase;
 
 public class BadWordControllerTest extends TestCase
 {
-
-    
-    public void testCRUD() 
-    {
-        BadWordController controller = new BadWordController();
-        String word = Util.createUniqueTimeStamp();
-        controller.addBadWord(word);
-
-        assertTrue(controller.list().contains(word));
-        
-        controller.removeBannedWord(word);
-        
-        assertFalse(controller.list().contains(word));
-        
-        
-        
-    }
+	public void testCRUD()
+	{
+		final BadWordController controller = new BadWordController();
+		final String word = Util.createUniqueTimeStamp();
+		controller.addBadWord(word);
+		assertTrue(controller.list().contains(word));
+		controller.removeBannedWord(word);
+		assertFalse(controller.list().contains(word));
+	}
 }
